#!/bin/sh
# install snaps specified by sideloads.snap config, but sideloading the files 
# downloaded from a swift container as we shouldn't depend on the snap store 
# to deploy it
#
# to use this script ols-vms of the project must define the following configs:
# vm.setup_scripts, sideload.snaps and sideload.snaps.url.
# sideload.snaps must be ordered based on snaps dependencies
# 
# Example using charm snap: 
#
# vm.setup_scripts = /var/lib/jenkins/jenkaas/scripts/snap-sideload.sh
# sideload.snaps = core18_1705 snapd_6434 charm_440 
# sideload.snaps.url = https://objectstorage.openstack.example.com/v1/AUTH_87d7a2fd240a42268e56eae27cd2f9ae/charm-snap-dependencies
#
set -e
TMP_DIR=$(mktemp -d /tmp/charm-tools-deps.XXXX) # might help avoid surprises/stale files?

# cleanup temporary directory on exit
trap 'rm -rf "$TMP_DIR"' EXIT

SWIFT_URL="{sideload.snaps.url}"
SNAPS_TO_INSTALL="{sideload.snaps}"
for snap_file in $SNAPS_TO_INSTALL
do
    echo "Downloading $snap_file (assert and snap)"
    curl -s -o $TMP_DIR/$snap_file.assert $SWIFT_URL/$snap_file.assert
    curl -s -o $TMP_DIR/$snap_file.snap $SWIFT_URL/$snap_file.snap
    sudo snap ack $TMP_DIR/$snap_file.assert
    # FIXME: find a nice way to mark which snaps require classic instead of 
    # hardoding the check here
	case $snap_file in
      "charm"*) sudo snap install $TMP_DIR/$snap_file.snap --classic ;;
      *)      sudo snap install $TMP_DIR/$snap_file.snap ;;
    esac
done
